#####################
# This program may be used, executed, copied, modified and distributed
# without royalty for the purpose of developing, using, marketing, or distribution
#####################

import sys

from time import sleep
from java.io import File
from java.lang import String
import java

#-------------------------------------------------------
# get the line separator and use to do the parsing 
# since the line separator on different platform are different
lineSeparator = java.lang.System.getProperty('line.separator')
#-------------------------------------------------------

#-------------------------------------------------------------------------------
# variables to save the return values
#-------------------------------------------------------------------------------
cellName = ""
flag = "base"
securityId = ""
ltpaId = ""
swamId = ""
secMbean = ""
privateKey = ""
publicKey = ""
sharedKey = ""
debugFile = ""
debugFileName="securityConfig"
returnCode=0

#input default values
cmd = "unknown"
ltpaCmd=""
loginCmd=""
pwdLTPA = "iscpass"
fileLTPA = "ltpa"
activeMechanism="LTPA"
domainName=""
enable="true"
debug="file"
force="true"
usage = "false"
fullusage = "false"
LTPAalreadyPresent="false"
serverName="server1"
returnCode=0

#-------------------------------------------------------------------------------
# utils
#-------------------------------------------------------------------------------


def toArray(list, sep=lineSeparator):
    array = []
    if (list != ""):
        array = list.split(sep)
    return array

def getId(cell, node, server=None, type=None, name=None):
    id = ''
    if cell:
      id = '/Cell:' + cell
    if node:
      id = id + '/Node:' + node
    if server:
      id = id + '/Server:' + server
    if type:
      id = id + '/' + type + ':'
      if name:
        id = id + name
    if id:
      id = id + '/'
    return AdminConfig.getid(id)

def AdminConfig_getid(id):
    return AdminConfig.getid(id)

def AdminConfig_list(type, id):
    if not id:
        return []
    return toArray(AdminConfig.list(type, id))

def AdminConfig_listTemplates(templateType, templateName):
    return toArray(AdminConfig.listTemplates(templateType, templateName))

def findTemplate(templateType, attrName, templateName):
    templates = AdminConfig_listTemplates(templateType, templateName)
    for template in templates:
      if (AdminConfig.showAttribute(template, attrName) == templateName):
        return template
    return None

def AdminConfig_showAttribute(id, attr):
    if not id:
        return []
    val = AdminConfig.showAttribute(id, attr)
    if not val:
        return []
    if (val[0] != '['):
        return [val]
    return toArray(val[1:-1], ' ')

def find(scopeId, type, attrName = None, attrValue = None):
    rc = 0
    ids = AdminConfig_list(type, scopeId)
    for id in ids:
      if attrName:
        if (AdminConfig.showAttribute(id, attrName) != attrValue):
          id = None
      if id:
		return id
    return None

def remove(scopeId, type, attrName = None, attrValue = None):
    rc = 0
    ids = AdminConfig_list(type, scopeId)
    for id in ids:
      if attrName:
        if (AdminConfig.showAttribute(id, attrName) != attrValue):
          id = None
      if id:
        AdminConfig.remove(id)
        rc = 1
    return rc

def _print(str=''):
    global debugFile, debug
    terminator="\n"
    if (debug == 'file') or (debug == 'both'):
      debugFile.write(str + terminator)
    elif (debug == 'out') or (debug == 'both'):
      print str

def _printEntry(methodName):
    _print("****************************************\n")
    str = methodName + "======> ENTRY\n";
    _print(str)
    _print("****************************************\n")		



#-------------------------------------------------------------------------------
# check if base or nd environment
#-------------------------------------------------------------------------------
def whatEnv():
    global AdminControl, lineSeparator, cellName, flag, returnCode
    _printEntry("whatEnv")

    nodeName = AdminControl.getNode()
    _print("nodeName:" + nodeName)
    cellName = AdminControl.getCell()
    _print("cellName :" + cellName)
    command = "AdminControl.completeObjectName('type=Server,node=" + nodeName + ",cell=" + cellName + ",*')"
    _print("command :" + command)
    serverList = eval(command)
    server = serverList.split(lineSeparator)[0]
    processType = AdminControl.getAttribute(server,'processType')
    _print("processType:" + processType)
    # find out what environment
    if processType == "DeploymentManager":
	# nd environment
        flag = 'nd'
    elif (processType == "ManagedProcess" or processType == "NodeAgent"):
	_print("This script was not run by connecting to dmgr process\n")
	_print("Please rerun the script connecting to dmgr process\n")
	returnCode=1
	return
    elif processType == "UnManagedProcess":
        # base environment
        flag = 'base'

#-------------------------------------------------------------------------------
# get Security id
#-------------------------------------------------------------------------------
def getSecId():
    global AdminControl, AdminConfig, securityId, cellName, returnCode
    _printEntry("getSecId")
    
    try:
	param = "/Cell:" + cellName + "/Security:/"
        securityId = AdminConfig.getid(param)
        if len(securityId) == 0:
            _print("Security ConfigId was not found\n")
            returnCode=1
            return

        _print("got Security ConfigId is " + securityId + "\n")
    except:
        returnCode=1
        _print("AdminConfig.getid(" + param + ") caught an exception\n")


#-------------------------------------------------------------------------------
# get LTPA config id
#-------------------------------------------------------------------------------
def getLTPAId():
    global AdminConfig, lineSeparator, ltpaId, returnCode
    _printEntry("getLTPAId")

    try:
        ltpaObjects = AdminConfig.list("LTPA")
        if len(ltpaObjects) == 0:
            _print("LTPA ConfigId was not found\n")
            returnCode=1
            return

        ltpaId = ltpaObjects.split(lineSeparator)[0]
        _print("got LTPA ConfigId is " + ltpaId + "\n")
    except:
        returnCode=1
        _print("AdminConfig.list('LTPA') caught an exception\n")
    return

#-------------------------------------------------------------------------------
# get SWAM config id
#-------------------------------------------------------------------------------
def getSWAMId():
    global AdminConfig, lineSeparator, swamId, returnCode
    _printEntry("getSWAMId")
    
    try:
        swamObjects = AdminConfig.list("SWAMAuthentication")
        if len(swamObjects) == 0:
            _print("SWAMAuthentication ConfigId was not found\n")
            returnCode=1
            return

        swamId = swamObjects.split(lineSeparator)[0]
        _print("got SWAMAuthentication ConfigId is " + swamId + "\n")
    except:
        returnCode=1
        _print("AdminConfig.list('SWAMAuthentication') caught an exception\n")
    return

#-------------------------------------------------------------------------------
# get the SecurityAdmin mbean
#-------------------------------------------------------------------------------
def getSecurityAdminMbean(serverName):
    global AdminControl, lineSeparator, secMbean, flag, returnCode
    _printEntry("getSecurityAdminMbean")
    
    if flag == 'nd':
       try:
          secMbeans = AdminControl.queryNames('WebSphere:type=SecurityAdmin,process=dmgr,*')
          if len(secMbeans) == 0:
             returnCode=1
             _print("Security Mbean was not found\n")
             return

          secMbean = secMbeans.split(lineSeparator)[0]
          _print("got Security Mbean is " + secMbean + "\n")
       except:
          returnCode=1
          _print("AdminControl.queryNames('WebSphere:type=SecurityAdmin,process=dmgr,*') caught an exception\n")
          return
    else:
       try:
          queryStr = "WebSphere:type=SecurityAdmin,process="+serverName+",*"
          #print queryStr
          #queryStr = 'WebSphere:type=SecurityAdmin,process=server1,*'
          secMbeans = AdminControl.queryNames(queryStr) 
          if len(secMbeans) == 0:
             returnCode=1
             _print("Security Mbean was not found\n")
             return

          secMbean = secMbeans.split(lineSeparator)[0]
          _print("got Security Mbean is " + secMbean + "\n")
       except:
          returnCode=1
          _print("AdminControl.queryNames('WebSphere:type=SecurityAdmin,process="+serverName+",*') caught an exception\n")
          return
     

#-------------------------------------------------------------------------------
# generate LTPA keys
#-------------------------------------------------------------------------------
def generateLTPAKeys():
    global AdminControl, secMbean, pwdLTPA, returnCode
    _printEntry("generateLTPAKeys")
    if len(secMbean) != 0:
        try:
            _print("generating..")
            keys = AdminControl.invoke(secMbean, "generateKeys", pwdLTPA)
            _print("LTPA keys was generated\n")
        except:
            returnCode=1
            _print("AdminControl.invoke(" + secMbean + ", 'generateKeys', " + pwdLTPA + ") caught an exception\n")
    return

#-------------------------------------------------------------------------------
# exportLTPAKeysOnline to get the key value to set private, public and shared key
#-------------------------------------------------------------------------------
def exportLTPAKeysOnline(fileName):
    global AdminControl, secMbean, privateKey, publicKey, sharedKey, returnCode
    _printEntry("exportLTPAKeysOnline")    

    if len(secMbean) != 0:
        try:
            _print("exporting..")
            temp = AdminControl.invoke(secMbean, "exportLTPAKeys")
        except:
            returnCode=1
            _print("AdminControl.invoke(" + secMbean + ", 'exportLTPAKeysOnline') caught an exception\n")
            return
        _print(temp)
        # trim the beginning [ [
        temp1 = temp.split("[ [")[1]
        temp2 = temp1.split("] ]")[0]
        result = temp2
        _print("result: " + result + "\n")

        if len(result) != 0:
           _print("opening new file for storing ltpa keys")
           file = open(fileName, "w") # 
	     # get shared key value
           _print("parsing array of keys:" + "\n")
           x = [1,2,3,4,5,6]
           i=1
           counter=0
           while counter<3: 
              temp = result.split("] [") [i]
              _print("temp: " + temp)
              key=""
              value=""
              array = []
              if (temp != ""):
                array = temp.split(" ")
                key = array[0]
                value = array[1]
                _print("key: " + key + ", value: " + value)

              if (key.find("com.ibm.websphere.ltpa.3DESKey") != -1):
                 counter = counter + 1
                 sharedKey = value
                 str = "com.ibm.websphere.ltpa.3DESKey" + "=" + value + "\n"
                 file.write(str)
                 _print("str: " + str)
              elif (key.find("com.ibm.websphere.ltpa.PrivateKey") != -1):
                 counter = counter + 1
                 privateKey = value
                 str = "com.ibm.websphere.ltpa.PrivateKey" + "=" + value + "\n"
                 file.write(str)
                 _print("str: " + str)
              elif (key.find("com.ibm.websphere.ltpa.PublicKey") != -1):
                 counter = counter + 1
                 publicKey = value
                 str = "com.ibm.websphere.ltpa.PublicKey" + "=" + value + "\n"
                 file.write(str)
                 _print("str: " + str)
              i = i + 1

           file.close();
           _print("public, private, and shared keys exported\n")
        else:
            _print("exportLTPAKey returns empty string")


#-------------------------------------------------------------------------------
# export the LTPA keys in offline mode using AdminConfig
#-------------------------------------------------------------------------------

def exportLTPAKeysOffLine(fileName):
    global AdminConfig, privateKey, publicKey, sharedKey, returnCode
    _printEntry("exportLTPAKeysOffLine ")    
    keys = toArray(AdminConfig.list('Key'))
   
    _print("opening new file for storing ltpa keys")
    file = open(fileName, "w")

    keyValue = AdminConfig.showAttribute(keys[0], 'byteArray')
    str = "com.ibm.websphere.ltpa.PrivateKey" + "=" + keyValue + "\n"
    privateKey = keyValue
    file.write(str)
    _print(str)
    keyValue = AdminConfig.showAttribute(keys[1], 'byteArray')
    str = "com.ibm.websphere.ltpa.PublicKey" + "=" + keyValue + "\n"
    publicKey = keyValue
    file.write(str)
    _print(str)
    keyValue = AdminConfig.showAttribute(keys[2], 'byteArray')
    str = "com.ibm.websphere.ltpa.3DESKey" + "=" + keyValue + "\n"
    sharedKey = keyValue
    file.write(str)
    _print(str)
    file.close();
    _print("public, private, and shared keys exported\n")


def checkLTPAKeysAlreadyPresent(fileName):
    global privateKey, publicKey, sharedKey, LTPAalreadyPresent, returnCode, returnCode

    _printEntry("checkLTPAKeysAlreadyPresent ")    

    keys=AdminConfig.list('Key')
    if keys: 
        exportLTPAKeysOffLine(fileName)
        returnCode = 0

    if (privateKey != '' and publicKey !='' and sharedKey !=''):
        LTPAalreadyPresent = "true"
        _print("LTPA already present..")
    else:
        LTPAalreadyPresent = "false"
        _print("LTPA already not present..")

#-------------------------------------------------------------------------------
# setup attribute values for AuthenticationMechanism using LTPA ConfigId
#-------------------------------------------------------------------------------
def doLTPAAuthenticationMechanism():
    global AdminConfig, domainName, ltpaId, pwdLTPA, privateKey, publicKey, sharedKey, returnCode
    _printEntry("doLTPAAuthenticationMechanism")    

    _print("domainName: " + domainName)
    _print("ltpaId: " + ltpaId)
    _print("sharedKey: " + sharedKey)
    _print("privateKey: " + privateKey)
    _print("publicKey: " + publicKey)
    
    attrs = [["password", pwdLTPA], ["singleSignon", [["requiresSSL", "false"], ["domainName", domainName], ["enabled", "true"]]], ["private", [["byteArray", privateKey]]], ["public", [["byteArray", publicKey]]], ["shared", [["byteArray", sharedKey]]]] 
    if len(ltpaId) > 0:
        try:
            AdminConfig.modify(ltpaId, attrs)
            try:
                AdminConfig.save()
                _print("Updated was saved successfully\n")
            except:
                returnCode=1
                _print("AdminConfig.save() caught an exception\n")
        except:
            returnCode=1
            _print("AdminConfig.modify(" + ltpaId + ", " + attrs + ") caught an exception\n")
    else:
        returnCode=1
        _print("Any was not found\n")
    return
     
            
#-------------------------------------------------------------------------------
# enable LTPA Security
#-------------------------------------------------------------------------------
def doLTPAActiveMechanism():
    global AdminConfig, securityId, ltpaId, returnCode
    _printEntry("doLTPAActiveMechanism")    

    attrs = [["activeAuthMechanism", ltpaId]]
    
    if (len(securityId) > 0) or (len(ltpaId) > 0):
        try:
            AdminConfig.modify(securityId, attrs)
            try:
                AdminConfig.save()
                returnCode=1
                _print("Updated was saved successfully\n")
            except:
                returnCode=1
                _print("AdminConfig.save() caught an exception\n")
        except:
            returnCode=1
            _print("AdminConfig.modify(" + securityId + ", " + attrs + ") caught an exception\n")
    else:
        returnCode=1
        _print("Any was not found\n")
    return


#-------------------------------------------------------------------------------
# enable active authentication mechanism
#-------------------------------------------------------------------------------
def doActiveMechanism(authenticationId):
    global AdminConfig, securityId, returnCode
    _printEntry("doActiveMechanism")    

    attrs = [["activeAuthMechanism", authenticationId]]
    
    if (len(securityId) > 0) or (len(authenticationId) > 0):
        try:
            AdminConfig.modify(securityId, attrs)
            try:
                AdminConfig.save()
                _print("Updated was saved successfully\n")
            except:
                returnCode=1
                _print("AdminConfig.save() caught an exception\n")
        except:
            returnCode=1
            _print("AdminConfig.modify(" + securityId + ", " + attrs + ") caught an exception\n")
    else:
        returnCode=1
        _print("Any was not found\n")
    return


#-------------------------------------------------------------------------------
# enable security
#-------------------------------------------------------------------------------
def doSecurityEnable():
    global AdminConfig, securityId, returnCode
    _printEntry("doSecurityEnable")    

    attrs = [["enabled", "true"]]
    
    if (len(securityId) > 0):
        try:
            AdminConfig.modify(securityId, attrs)
            try:
                AdminConfig.save()
                _print("Updated was saved successfully\n")
            except:
                returnCode=1
                _print("AdminConfig.save() caught an exception\n")
        except:
            returnCode=1
            _print("AdminConfig.modify(" + securityId + ", " + attrs + ") caught an exception\n")
    else:
        returnCode=1
        _print("Security configId was not found\n")
    return


#-------------------------------------------------------------------------------
# disable security
#-------------------------------------------------------------------------------
def doSecurityDisable():
    global AdminConfig, securityId, returnCode
    _printEntry("doSecurityDisable")    
    
    attrs = [["enabled", "false"]]
    
    if len(securityId) > 0:
        try:
            AdminConfig.modify(securityId, attrs)
            try:
                AdminConfig.save()
                _print("Updated was saved successfully\n")
            except:
                returnCode=1
                _print("AdminConfig.save() caught an exception\n")
        except:
            returnCode=1
            _print("AdminConfig.modify(" + securityId + ", " + attrs + ") caught an exception\n")
    else:
        returnCode=1
        _print("Security configId was not found\n")
    return


#-------------------------------------------------------------------------------
# force to do the sync here and put in wait to give time for sync to finish
#-------------------------------------------------------------------------------
def forceSync():
    global AdminControl , returnCode
    _printEntry("forceSync")    
    
    try:
        nodeSyncObjects = AdminControl.queryNames("type=NodeSync,*")
        if len(nodeSyncObjects) > 0:
            nodeSyncObjectList = nodeSyncObjects.split("\r\n")
            for nodeSync in nodeSyncObjectList:
                syncResult = "false"
                while syncResult != "true":
                    _print("Force NodeSync on " + nodeSync)
                    try:
                        syncResult = AdminControl.invoke(nodeSync, "sync", "")
                        _print("Sync result on " + nodeSync + " is " + syncResult)
                    except:
                        returnCode=1
                        _print("AdminControl.invoke(" + nodeSync + ", 'sync', '') caught an exception\n")
            _print("Time out for 1 minute to make sure sync is done")
            sleep(45) 
    except:
        returnCode=1
        _print("AdminControl.queryNames('type=NodeSync,*') caught an exception\n")
    return

#-------------------------------------------------------------------------------
# Remove the LTPA keys and password
#-------------------------------------------------------------------------------
def removeLTPA():
   global AdminConfig, ltpaId, returnCode
   _printEntry("removeLTPA")    

   if len(ltpaId) > 0:
        try:
            keys = toArray(AdminConfig.list('Key'))
            attrs = [['byteArray', '']]
            AdminConfig.modify(keys[0], attrs)
            AdminConfig.modify(keys[1], attrs)
            AdminConfig.modify(keys[2], attrs)
            attrs = [["password", '']] 
            AdminConfig.modify(ltpaId, attrs)
            try:
                AdminConfig.save()
                _print("Updated was saved successfully\n")
            except:
                returnCode=1
                _print("AdminConfig.save() caught an exception\n")
        except:
            returnCode=1
            _print("AdminConfig.modify(" + ltpaId + ", " + attrs + ") caught an exception\n")
   else:
        returnCode=1
        _print("Any was not found\n")
   return



#-----------------------------------------------------------------
# Parse the input params and options
#-----------------------------------------------------------------

def processArguments(args):
   global ltpaCmd, loginCmd, activeMechanism, force, fileLTPA, pwdLTPA, domainName, debug, fullusage, usage, serverName, returnCode
   _printEntry("processArguments")    

   skip = 0
   wrongParam = 'false';
   while (args and wrongParam == 'false'):
       count = len(args)
       if (args[0] == '-usage'):
            usage = "true"
            count = len(args)
            if count > 1  :
		 args=args[1:]
            else:
		 break
       if (args[0] == '-fullusage'):
            fullusage = "true"
            count = len(args)
            if count > 1  :
		 args=args[1:]
            else:
		 break
       if (args[0] == '-enable'):
            ltpaCmd = args[0]
            count = len(args)
            if count > 1  :
		 args=args[1:]
            else:
		 break
       elif (args[0] == '-disable'):
            ltpaCmd = args[0]
            count = len(args)
            if count > 1  :
		 args=args[1:]
            else:
		 break
       elif (args[0] == '-pwdLTPA'):
            pwdLTPA = args[1]
            count = len(args)
            if count > 2  :
		 args=args[2:]
            else:
		 break
       elif (args[0] == '-serverName'):
            serverName = args[1]
            count = len(args)
            if count > 2  :
		 args=args[2:]
            else:
		 break
       elif (args[0] == '-domainName'):
            domainName = args[1]
            count = len(args)
            if count > 2  :
		 args=args[2:]
            else:
		 break
       elif count > 1  :
   	     # skip args without flag
	     if (skip == 2):
   	        fileLTPA = args[0]
	     if (skip == 3):
   	        pwdLTPA = args[0]
	     args=args[1:]
   	     skip = skip +1
       else:
	      wrongParam = 'true'
	      returnCode = 1


   _print("recap parms and options")   

   _print("ltpaCmd: " + ltpaCmd)   
   _print("fileLTPA: " + fileLTPA)
   _print("activeMechanism: " + activeMechanism)   
   _print("loginCmd: " + loginCmd)   
   _print("domainName: " + domainName)   
   _print("force: " + force)   
   _print("enable: " + enable)      
   _print("debug: " + debug)   

#-----------------------------------------------------------------
# full  help with the only options available for the administrator of the TWS WEBUI
#-----------------------------------------------------------------
def helpfullusage():
    print '\nUsage: -disable|{enable [-serverName <app server name>] [-pwdLTPA <LTPA password>]}'
    print '\nwhere:'
    print '\n-enable, disable the TWS to work with the TWS WebUI'
    print '<LTPA password>, password specified when the LTPA keys has been created.'
    print '<app server name>, application server name updated with the new LTPA, default server name is server1'
   
    print '\nExamples:'

    print '\n1) enable: this operation must be performed with the TWS application server started:'
    print '\nwsadmin -conntype SOAP -port <SOAP port> -username <your was user> -password <your was user pwd> -lang jython -f <WAS_TOOLS_PATH>/webui.py -enable -serverName server1 -pwdLTPA <LTPA password>'

    print '\n2) disable: this operation can be performed also with the TWS application server stopped:'
    print '\nwsadmin -conntype NONE -lang jython -f <WAS_TOOLS_PATH>/webui.py -disable'

    print '\nWAS parameters:'
    print '<SOAP port>, SOAP port of the <application server name>'
    print '<your was user>, user name defined in the WAS user registry'
    print '<your was user pwd>, password of the WAS user'

#-----------------------------------------------------------------
# full  help with the only options available for the administrator of the TWS WEBUI
#-----------------------------------------------------------------
def helpusage():
    print '\nUsage: -enable|disable'
    print '\nwhere:'
    print '\n-enable, disable the web interface of the TWS'

    print '\nExamples:'

    print '\n1) enable: this operation must be performed with the TWS application server started:'
    print '\nwsadmin -conntype SOAP -port <SOAP port> -username <your was user> -password <your was user pwd> -lang jython -f <WAS_TOOLS_PATH>/webui.py -enable'

    print '\n2) disable: this operation can be performed also with the TWS application server stopped:'
    print '\nwsadmin -conntype NONE -lang jython -f <WAS_TOOLS_PATH>/webui.py -disable'

    print '\nWAS parameters:'
    print '<SOAP port>, SOAP port of the <application server name>'
    print '<your was user>, user name defined in the WAS user registry'
    print '<your was user pwd>, password of the WAS user'


#-----------------------------------------------------------------
# Main
#-----------------------------------------------------------------
def main(argv=None):
    global cmd, fileLTPA, pwdLTPA, debugFile, debugFileName, returnCode,serverName, returnCode

    global AdminConfig

    if (debug == 'file'):
      debugFilePathName = File.createTempFile(debugFileName,".log").getPath()
      debugFile = open(debugFilePathName, "w")

    _print("****************************************")
    _print("***   Security Configuration: Start  ***")
    _print("****************************************")
   
    if argv is None:
         argv = sys.argv

    processArguments(argv)

    if (fullusage == 'true'):
         helpfullusage()
         return returnCode

    if (usage == 'true'):
         helpusage()
         return returnCode

    if (ltpaCmd == ''):
         returnCode = 1
         helpusage()
         return returnCode
    try:

         getSecId()

         getLTPAId()

         getSWAMId()

         if (ltpaCmd == '-enable'):
            checkLTPAKeysAlreadyPresent(fileLTPA)

            if (LTPAalreadyPresent == 'false' or force =='true'):
               _print("LTPA keys not present,  they will be created now")
               whatEnv()

               getSecurityAdminMbean(serverName)

               generateLTPAKeys()

               tempFileLTPA=File.createTempFile("ltpa",".properties")
               fileLTPA=tempFileLTPA.getPath()

               exportLTPAKeysOnline(fileLTPA)

               doLTPAAuthenticationMechanism()

               doActiveMechanism(ltpaId)

               doSecurityEnable()

#               tempFileLTPA.delete()
               print"\nLTPA token has been exported to file " + fileLTPA

               forceSync()

         if (ltpaCmd == '-disable'):
            doActiveMechanism(swamId)

            getLTPAId()

            removeLTPA()

         if (returnCode == 0):
            print "\nConfiguration successfully completed."
         if (returnCode == 1):
            print "\nConfiguration failed."

         if (debugFilePathName !=''):
            print "\nDebug log: " + debugFilePathName

         _print("****************************************")
         _print("***   Security Configuration: End    ***")
         _print("****************************************")

         debugFile.close()
         return returnCode
    except:
        AdminConfig.reset()
        returnCode = 1
        print "\nConfiguration failed."
        return returnCode
    else:
        AdminConfig.save()
        return returnCode

if __name__ == "main":
  sys.exit(main())

