#!/bin/sh
                                                                                
#########################################################################
#
# (C) Copyright IBM Corporation 2003-2007
# Unpublished Work
# All Rights Reserved
# Licensed Material - Property of IBM Corporation.
#
# This script configure the webui
#
# Launch it in your session, within the dir where it is located
#
#########################################################################

usage()
{
  echo "Usage: webui.sh -operation <disable|enable> [-user <username> -password <password>] [-port <port>] [-pwdLTPA <password>] [-server <Server Name>]"
}

# VARIABLES 
PORT=31118
SERVERNAME=server1
PROFILE=twszconnprofile
PWDLTPA=iscpass

# CHECK ROOT USER
WHO=`id | cut -f1 -d" "`
if [ ! "$WHO" = "uid=0(root)" ]
then
       echo "ERROR: only the root user can run this script"
       exit 1
fi

# AT LEAST ONE PARAMETER
if [ $# -lt 1 ]
then
   usage
   exit 1
fi


# PARSE COMMAND LINE
while [ $# -gt 0 ]
do
   CPARM=$1; export CPARM
   shift
 
   case $CPARM in
 
      -u)
          usage
          exit 0
      ;;
 
      -user)
         USERID=$1; export USERID
         shift
      ;;
 
      -password)
         PASSWORD=$1; export PASSWORD
         shift
      ;;

      -port)
         PORT=$1; export PORT
         shift
      ;;

      -pwdLTPA)
         PWDLTPA=$1; export PWDLTPA
         shift
      ;;

      -server)
         SERVERNAME=$1; export SERVERNAME
         shift
      ;;

      -operation)
         OPERATION=$1; export OPERATION
         shift
      ;;

 
      *)
         usage
         exit 1
      ;;
 
   esac
done

if [ -z "OPERATION" ]
then
    usage
    exit 1
fi

# GET THE CURRENT DIR AND MOVE TO THE WASTOOLS DIR
LAUNCHDIR=`dirname $0`
STARTDIR=`pwd`
cd $LAUNCHDIR
CURRENTDIR=`pwd`

# RUN WSADMIN
if [ "$OPERATION" = "enable" ] ; then
     # VALIDATE INPUT 
     if [ -z "$USERID" ]
     then
         usage
         exit 1
     fi
      
     if [ -z "$PASSWORD" ]
     then
         usage
         exit 1
     fi
      
     if [ -z "PORT" ]
     then
         usage
         exit 1
     fi

    $CURRENTDIR/../appserver/profiles/$PROFILE/bin/wsadmin.sh -conntype SOAP -user "$USERID" -password "$PASSWORD" -port "$PORT" -lang jython -f "$CURRENTDIR/webui.py" -$OPERATION -serverName "$SERVERNAME" -pwdLTPA "$PWDLTPA"
    RC=$?
else
    if [ "$OPERATION" = "disable" ] ; then
        $CURRENTDIR/../appserver/profiles/$PROFILE/bin/wsadmin.sh -conntype NONE -lang jython -f $CURRENTDIR/webui.py -$OPERATION -serverName $SERVERNAME
        RC=$?
    fi
fi

# GO BACK TO START DIR
cd $STARTDIR 
 
exit $RC



